========
USGS API
========

`USGS` is a python module for interfacing with the US Geological Survey's API. It provides submodules to interact with various endpoints, and command line utilities, helpful for building out large pipelines.

Documentation is available at:

http://kapadia.github.io/usgs/


ChangeLog
========

 0.2.6   Carl.andrson@nltgis.com
         Remove dependency on pyproj and shapely and use great circle computation to expand a point search to a box
